@@ -45,6 +45,17 @@ class CloseIO(object):
     def delete_lead(self, lead_id):
         return self._api.lead(lead_id).delete()
 
+    @parse_response
+    @handle_errors
+    def delete_email_template(self, template_id):
+        return self._api.email_template(template_id).delete()
+
+    @parse_response
+    @handle_errors
+    def create_email_template(self, fields):
+        fields = convert(fields)
+        return self._api.email_template.post(fields)
+
     @parse_response
     @handle_errors
     def get_email_templates(self):
